@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -36,11 +36,10 @@
 using namespace KPIMTextEdit;
 
 TextEditFindBarBase::TextEditFindBarBase(QWidget *parent)
-    : QWidget(parent),
-      mHideWhenClose(true)
+    : QWidget(parent)
+    , mHideWhenClose(true)
 {
     QVBoxLayout *topLayout = new QVBoxLayout;
-    //topLayout->setMargin(0);
     QHBoxLayout *lay = new QHBoxLayout;
     topLayout->addLayout(lay);
 
@@ -150,17 +149,14 @@ void TextEditFindBarBase::autoSearch(const QString &str)
 
 void TextEditFindBarBase::messageInfo(bool backward, bool isAutoSearch, bool found)
 {
+    Q_UNUSED(backward);
     if (!found && !isAutoSearch) {
         QString str = mLastSearchStr;
         if (str.length() > 39) {
             str.truncate(40);
             str += QLatin1String("...");
         }
-        if (backward) {
-            Q_EMIT displayMessageIndicator(i18n("End of message reached.\nPhrase '%1' could not be found.", str));
-        } else {
-            Q_EMIT displayMessageIndicator(i18n("End of message reached.\nPhrase '%1' could not be found.", str));
-        }
+        Q_EMIT displayMessageIndicator(i18n("End of message reached.\nPhrase '%1' could not be found.", str));
     }
 }
 
@@ -237,8 +233,8 @@ bool TextEditFindBarBase::event(QEvent *e)
             e->accept();
             closeBar();
             return true;
-        } else if (kev->key() == Qt::Key_Enter ||
-                   kev->key() == Qt::Key_Return) {
+        } else if (kev->key() == Qt::Key_Enter
+                   || kev->key() == Qt::Key_Return) {
             e->accept();
             if (shortCutOverride) {
                 return true;
@@ -257,4 +253,3 @@ bool TextEditFindBarBase::event(QEvent *e)
     }
     return QWidget::event(e);
 }
-
